<a id="types-aiobotocore-personalize"></a>

# types-aiobotocore-personalize

[![PyPI - types-aiobotocore-personalize](https://img.shields.io/pypi/v/types-aiobotocore-personalize.svg?color=blue)](https://pypi.org/project/types-aiobotocore-personalize)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-personalize.svg?color=blue)](https://pypi.org/project/types-aiobotocore-personalize)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-personalize?color=blue)](https://pypistats.org/packages/types-aiobotocore-personalize)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.Personalize 2.3.4](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/personalize.html#Personalize)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.10.0](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-personalize docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_personalize/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-personalize](#types-aiobotocore-personalize)
  - [How to install](#how-to-install)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `Personalize` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[personalize]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[personalize]'


# standalone installation
python -m pip install types-aiobotocore-personalize
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-personalize
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[personalize]` in your environment:

```bash
python -m pip install 'types-aiobotocore[personalize]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[personalize]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[personalize]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[personalize]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[personalize]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[personalize]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[personalize]` in your environment:

```bash
python -m pip install 'types-aiobotocore[personalize]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[personalize]` in your environment:

```bash
python -m pip install 'types-aiobotocore[personalize]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`PersonalizeClient` provides annotations for
`session.create_client("personalize")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_personalize import PersonalizeClient

session = get_session()
async with session.create_client("personalize") as client:
    client: PersonalizeClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_personalize.paginator` module contains type annotations for
all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_personalize import PersonalizeClient
from types_aiobotocore_personalize.paginator import (
    ListBatchInferenceJobsPaginator,
    ListBatchSegmentJobsPaginator,
    ListCampaignsPaginator,
    ListDatasetExportJobsPaginator,
    ListDatasetGroupsPaginator,
    ListDatasetImportJobsPaginator,
    ListDatasetsPaginator,
    ListEventTrackersPaginator,
    ListFiltersPaginator,
    ListRecipesPaginator,
    ListRecommendersPaginator,
    ListSchemasPaginator,
    ListSolutionVersionsPaginator,
    ListSolutionsPaginator,
)

session = get_session()
async with session.create_client("personalize") as client:
    client: PersonalizeClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_batch_inference_jobs_paginator: ListBatchInferenceJobsPaginator = client.get_paginator("list_batch_inference_jobs")
        list_batch_segment_jobs_paginator: ListBatchSegmentJobsPaginator = client.get_paginator("list_batch_segment_jobs")
        list_campaigns_paginator: ListCampaignsPaginator = client.get_paginator("list_campaigns")
        list_dataset_export_jobs_paginator: ListDatasetExportJobsPaginator = client.get_paginator("list_dataset_export_jobs")
        list_dataset_groups_paginator: ListDatasetGroupsPaginator = client.get_paginator("list_dataset_groups")
        list_dataset_import_jobs_paginator: ListDatasetImportJobsPaginator = client.get_paginator("list_dataset_import_jobs")
        list_datasets_paginator: ListDatasetsPaginator = client.get_paginator("list_datasets")
        list_event_trackers_paginator: ListEventTrackersPaginator = client.get_paginator("list_event_trackers")
        list_filters_paginator: ListFiltersPaginator = client.get_paginator("list_filters")
        list_recipes_paginator: ListRecipesPaginator = client.get_paginator("list_recipes")
        list_recommenders_paginator: ListRecommendersPaginator = client.get_paginator("list_recommenders")
        list_schemas_paginator: ListSchemasPaginator = client.get_paginator("list_schemas")
        list_solution_versions_paginator: ListSolutionVersionsPaginator = client.get_paginator("list_solution_versions")
        list_solutions_paginator: ListSolutionsPaginator = client.get_paginator("list_solutions")
    ```







### Literals

`types_aiobotocore_personalize.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_personalize.literals import (
    DomainType,
    IngestionModeType,
    ListBatchInferenceJobsPaginatorName,
    ListBatchSegmentJobsPaginatorName,
    ListCampaignsPaginatorName,
    ListDatasetExportJobsPaginatorName,
    ListDatasetGroupsPaginatorName,
    ListDatasetImportJobsPaginatorName,
    ListDatasetsPaginatorName,
    ListEventTrackersPaginatorName,
    ListFiltersPaginatorName,
    ListRecipesPaginatorName,
    ListRecommendersPaginatorName,
    ListSchemasPaginatorName,
    ListSolutionVersionsPaginatorName,
    ListSolutionsPaginatorName,
    ObjectiveSensitivityType,
    RecipeProviderType,
    TrainingModeType,
    PersonalizeServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)

def check_value(value: DomainType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_personalize.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_personalize.type_defs import (
    AlgorithmImageTypeDef,
    AutoMLConfigTypeDef,
    AutoMLResultTypeDef,
    BatchInferenceJobConfigTypeDef,
    S3DataConfigTypeDef,
    BatchInferenceJobSummaryTypeDef,
    BatchSegmentJobSummaryTypeDef,
    CampaignConfigTypeDef,
    CampaignSummaryTypeDef,
    CategoricalHyperParameterRangeTypeDef,
    ContinuousHyperParameterRangeTypeDef,
    ResponseMetadataTypeDef,
    CreateDatasetGroupRequestRequestTypeDef,
    DataSourceTypeDef,
    CreateDatasetRequestRequestTypeDef,
    CreateEventTrackerRequestRequestTypeDef,
    CreateFilterRequestRequestTypeDef,
    RecommenderConfigTypeDef,
    CreateSchemaRequestRequestTypeDef,
    CreateSolutionVersionRequestRequestTypeDef,
    DatasetExportJobSummaryTypeDef,
    DatasetGroupSummaryTypeDef,
    DatasetGroupTypeDef,
    DatasetImportJobSummaryTypeDef,
    DatasetSchemaSummaryTypeDef,
    DatasetSchemaTypeDef,
    DatasetSummaryTypeDef,
    DatasetTypeDef,
    DefaultCategoricalHyperParameterRangeTypeDef,
    DefaultContinuousHyperParameterRangeTypeDef,
    DefaultIntegerHyperParameterRangeTypeDef,
    DeleteCampaignRequestRequestTypeDef,
    DeleteDatasetGroupRequestRequestTypeDef,
    DeleteDatasetRequestRequestTypeDef,
    DeleteEventTrackerRequestRequestTypeDef,
    DeleteFilterRequestRequestTypeDef,
    DeleteRecommenderRequestRequestTypeDef,
    DeleteSchemaRequestRequestTypeDef,
    DeleteSolutionRequestRequestTypeDef,
    DescribeAlgorithmRequestRequestTypeDef,
    DescribeBatchInferenceJobRequestRequestTypeDef,
    DescribeBatchSegmentJobRequestRequestTypeDef,
    DescribeCampaignRequestRequestTypeDef,
    DescribeDatasetExportJobRequestRequestTypeDef,
    DescribeDatasetGroupRequestRequestTypeDef,
    DescribeDatasetImportJobRequestRequestTypeDef,
    DescribeDatasetRequestRequestTypeDef,
    DescribeEventTrackerRequestRequestTypeDef,
    EventTrackerTypeDef,
    DescribeFeatureTransformationRequestRequestTypeDef,
    FeatureTransformationTypeDef,
    DescribeFilterRequestRequestTypeDef,
    FilterTypeDef,
    DescribeRecipeRequestRequestTypeDef,
    RecipeTypeDef,
    DescribeRecommenderRequestRequestTypeDef,
    DescribeSchemaRequestRequestTypeDef,
    DescribeSolutionRequestRequestTypeDef,
    DescribeSolutionVersionRequestRequestTypeDef,
    EventTrackerSummaryTypeDef,
    FilterSummaryTypeDef,
    GetSolutionMetricsRequestRequestTypeDef,
    HPOObjectiveTypeDef,
    HPOResourceConfigTypeDef,
    IntegerHyperParameterRangeTypeDef,
    PaginatorConfigTypeDef,
    ListBatchInferenceJobsRequestRequestTypeDef,
    ListBatchSegmentJobsRequestRequestTypeDef,
    ListCampaignsRequestRequestTypeDef,
    ListDatasetExportJobsRequestRequestTypeDef,
    ListDatasetGroupsRequestRequestTypeDef,
    ListDatasetImportJobsRequestRequestTypeDef,
    ListDatasetsRequestRequestTypeDef,
    ListEventTrackersRequestRequestTypeDef,
    ListFiltersRequestRequestTypeDef,
    ListRecipesRequestRequestTypeDef,
    RecipeSummaryTypeDef,
    ListRecommendersRequestRequestTypeDef,
    ListSchemasRequestRequestTypeDef,
    ListSolutionVersionsRequestRequestTypeDef,
    SolutionVersionSummaryTypeDef,
    ListSolutionsRequestRequestTypeDef,
    SolutionSummaryTypeDef,
    OptimizationObjectiveTypeDef,
    TunedHPOParamsTypeDef,
    StopSolutionVersionCreationRequestRequestTypeDef,
    BatchInferenceJobInputTypeDef,
    BatchInferenceJobOutputTypeDef,
    BatchSegmentJobInputTypeDef,
    BatchSegmentJobOutputTypeDef,
    DatasetExportJobOutputTypeDef,
    CampaignUpdateSummaryTypeDef,
    CreateCampaignRequestRequestTypeDef,
    UpdateCampaignRequestRequestTypeDef,
    CreateBatchInferenceJobResponseTypeDef,
    CreateBatchSegmentJobResponseTypeDef,
    CreateCampaignResponseTypeDef,
    CreateDatasetExportJobResponseTypeDef,
    CreateDatasetGroupResponseTypeDef,
    CreateDatasetImportJobResponseTypeDef,
    CreateDatasetResponseTypeDef,
    CreateEventTrackerResponseTypeDef,
    CreateFilterResponseTypeDef,
    CreateRecommenderResponseTypeDef,
    CreateSchemaResponseTypeDef,
    CreateSolutionResponseTypeDef,
    CreateSolutionVersionResponseTypeDef,
    EmptyResponseMetadataTypeDef,
    GetSolutionMetricsResponseTypeDef,
    ListBatchInferenceJobsResponseTypeDef,
    ListBatchSegmentJobsResponseTypeDef,
    ListCampaignsResponseTypeDef,
    UpdateCampaignResponseTypeDef,
    UpdateRecommenderResponseTypeDef,
    CreateDatasetImportJobRequestRequestTypeDef,
    DatasetImportJobTypeDef,
    CreateRecommenderRequestRequestTypeDef,
    RecommenderSummaryTypeDef,
    RecommenderUpdateSummaryTypeDef,
    UpdateRecommenderRequestRequestTypeDef,
    ListDatasetExportJobsResponseTypeDef,
    ListDatasetGroupsResponseTypeDef,
    DescribeDatasetGroupResponseTypeDef,
    ListDatasetImportJobsResponseTypeDef,
    ListSchemasResponseTypeDef,
    DescribeSchemaResponseTypeDef,
    ListDatasetsResponseTypeDef,
    DescribeDatasetResponseTypeDef,
    DefaultHyperParameterRangesTypeDef,
    DescribeEventTrackerResponseTypeDef,
    DescribeFeatureTransformationResponseTypeDef,
    DescribeFilterResponseTypeDef,
    DescribeRecipeResponseTypeDef,
    ListEventTrackersResponseTypeDef,
    ListFiltersResponseTypeDef,
    HyperParameterRangesTypeDef,
    ListBatchInferenceJobsRequestListBatchInferenceJobsPaginateTypeDef,
    ListBatchSegmentJobsRequestListBatchSegmentJobsPaginateTypeDef,
    ListCampaignsRequestListCampaignsPaginateTypeDef,
    ListDatasetExportJobsRequestListDatasetExportJobsPaginateTypeDef,
    ListDatasetGroupsRequestListDatasetGroupsPaginateTypeDef,
    ListDatasetImportJobsRequestListDatasetImportJobsPaginateTypeDef,
    ListDatasetsRequestListDatasetsPaginateTypeDef,
    ListEventTrackersRequestListEventTrackersPaginateTypeDef,
    ListFiltersRequestListFiltersPaginateTypeDef,
    ListRecipesRequestListRecipesPaginateTypeDef,
    ListRecommendersRequestListRecommendersPaginateTypeDef,
    ListSchemasRequestListSchemasPaginateTypeDef,
    ListSolutionVersionsRequestListSolutionVersionsPaginateTypeDef,
    ListSolutionsRequestListSolutionsPaginateTypeDef,
    ListRecipesResponseTypeDef,
    ListSolutionVersionsResponseTypeDef,
    ListSolutionsResponseTypeDef,
    BatchInferenceJobTypeDef,
    CreateBatchInferenceJobRequestRequestTypeDef,
    BatchSegmentJobTypeDef,
    CreateBatchSegmentJobRequestRequestTypeDef,
    CreateDatasetExportJobRequestRequestTypeDef,
    DatasetExportJobTypeDef,
    CampaignTypeDef,
    DescribeDatasetImportJobResponseTypeDef,
    ListRecommendersResponseTypeDef,
    RecommenderTypeDef,
    AlgorithmTypeDef,
    HPOConfigTypeDef,
    DescribeBatchInferenceJobResponseTypeDef,
    DescribeBatchSegmentJobResponseTypeDef,
    DescribeDatasetExportJobResponseTypeDef,
    DescribeCampaignResponseTypeDef,
    DescribeRecommenderResponseTypeDef,
    DescribeAlgorithmResponseTypeDef,
    SolutionConfigTypeDef,
    CreateSolutionRequestRequestTypeDef,
    SolutionTypeDef,
    SolutionVersionTypeDef,
    DescribeSolutionResponseTypeDef,
    DescribeSolutionVersionResponseTypeDef,
)

def get_structure() -> AlgorithmImageTypeDef:
    return {
      ...
    }
```

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

## What's new

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

## Versioning

`types-aiobotocore-personalize` version is the same as related `aiobotocore`
version and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/)
format.

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_personalize/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
